@@ -75,9 +75,9 @@ function kontaktformular_render()
                 }
                 
                 if ($_SESSION["language"] == "de") {
-                    $fehler = "<p class='ulicms_error'>" . "Ihre Nachricht enthält nicht erlaubte Wörter.</p>";
+                    $fehler = "<p class='ulicms-error'>" . "Ihre Nachricht enthält nicht erlaubte Wörter.</p>";
                 } else {
-                    $fehler = "<p class='ulicms_error'>" . "Your comment contains not allowed words.</p>";
+                    $fehler = "<p class='ulicms-error'>" . "Your comment contains not allowed words.</p>";
                 }
             }
             
@@ -87,9 +87,9 @@ function kontaktformular_render()
                 setconfig("contact_form_refused_spam_mails", getconfig("contact_form_refused_spam_mails") + 1);
                 
                 if ($_SESSION["language"] == "de") {
-                    $fehler = "<p class='ulicms_error'>" . "Chinesische Schriftzeichen sind nicht erlaubt!</p>";
+                    $fehler = "<p class='ulicms-error'>" . "Chinesische Schriftzeichen sind nicht erlaubt!</p>";
                 } else {
-                    $fehler = "<p class='ulicms_error'>" . "Chinese chars are not allowed!</p>";
+                    $fehler = "<p class='ulicms-error'>" . "Chinese chars are not allowed!</p>";
                 }
             }
             // Filter nach russisch
@@ -98,9 +98,9 @@ function kontaktformular_render()
                 setconfig("contact_form_refused_spam_mails", getconfig("contact_form_refused_spam_mails") + 1);
                 
                 if ($_SESSION["language"] == "de") {
-                    $fehler = "<p class='ulicms_error'>" . "Kyrillische Schriftzeichen sind nicht erlaubt!</p>";
+                    $fehler = "<p class='ulicms-error'>" . "Kyrillische Schriftzeichen sind nicht erlaubt!</p>";
                 } else {
-                    $fehler = "<p class='ulicms_error'>" . "Cyrillic chars are not allowed!</p>";
+                    $fehler = "<p class='ulicms-error'>" . "Cyrillic chars are not allowed!</p>";
                 }
             }
             // Filter nach Land
